@@ -1,6 +1,8 @@
 from __future__ import print_function
 
 from bloom.generators import BloomGenerator
+from bloom.generators import check_metapackage_for_valid_cmake
+from bloom.generators import is_metapackage
 
 from bloom.git import inbranch
 from bloom.git import get_current_branch
@@ -9,6 +11,7 @@ from bloom.logging import error
 from bloom.logging import info
 from bloom.logging import warning
 
+from bloom.util import change_directory
 from bloom.util import execute_command
 from bloom.util import get_package_data
 
@@ -88,19 +91,17 @@ each package in the upstream repository, so the source branch should be set to
         # Figure out the version of the given package
         if self.name is not None:
             warning("""\
-Cannot automatically tag the release because this is not a catkin project."""
-            )
+Cannot automatically tag the release because this is not a catkin project.""")
             warning("""\
-Please checkout the release branch and then create a tag manually with:"""
-            )
+Please checkout the release branch and then create a tag manually with:""")
             warning("  git checkout release/" + str(self.name))
             warning("  git tag -f release/" + str(self.name) + "/<version>")
             return
         with inbranch(destination):
             name, version, packages = get_package_data(destination)
         # Execute git tag
-        execute_command('git tag -f ' + destination + '/' + version +
-            '-' + self.release_inc)
+        release_tag = destination + '/' + version + '-' + self.release_inc
+        execute_command('git tag ' + release_tag)
 
     def detect_branches(self):
         self.packages = None
@@ -110,4 +111,10 @@ Please checkout the release branch and then create a tag manually with:"""
                 return [self.name]
             name, version, packages = get_package_data(self.src)
             self.packages = packages
+            # Check meta packages for valid CMakeLists.txt
+            if isinstance(self.packages, dict):
+                for path, pkg in self.packages.iteritems():
+                    with change_directory(path):
+                        if is_metapackage(pkg):
+                            check_metapackage_for_valid_cmake(pkg.name)
             return name if type(name) is list else [name]
