@@ -37,6 +37,7 @@ from __future__ import print_function
 import os
 import functools
 import shutil
+import subprocess
 import tempfile
 
 from subprocess import PIPE
@@ -123,8 +124,14 @@ class GitClone(object):
                         with inbranch(branch):
                             cmd = 'git pull --rebase origin ' + branch
                             execute_command(cmd)
-                execute_command('git push --all')
-                execute_command('git push --tags')
+                execute_command('git push --all', silent=False)
+                try:
+                    execute_command('git push --tags', silent=False)
+                except subprocess.CalledProcessError:
+                    warning("Force pushing tags from clone to working repository, "
+                            "you will have to force push back to origin...")
+                    execute_command('git push --force --tags', silent=False)
+
         self.clean_up()
 
 
@@ -223,7 +230,7 @@ def ensure_clean_working_env(force=False, git_status=True, directory=None):
         error(code, exit=True)
     # Is it a git repo
     if get_root(directory) is None:
-        error("Not is a valid git repository", exit=True)
+        error("Not in a valid git repository", exit=True)
     # Are we on a branch?
     current_branch = get_current_branch(directory)
     if current_branch is None:
@@ -274,7 +281,7 @@ def checkout(reference, raise_exc=False, directory=None, show_git_status=True):
     debug("Checking out to " + str(reference))
     if reference == get_current_branch(directory):
         debug("Requested checkout reference is the same as the current branch")
-        return 0
+        return True
     fail_msg = ''
     git_root = get_root(directory)
     if git_root is not None:
@@ -550,6 +557,21 @@ def create_branch(branch, orphaned=False, changeto=False, directory=None):
             checkout(current_branch, directory=directory)
 
 
+def ensure_git_root():
+    """
+    Checks that you are in the root of the git repository, else exit.
+
+    :raises: SystemExit if this is not a valid git repository.
+    :raises: SystemExit if not in the root of a git repository.
+    """
+    root = get_root()
+    if root is None:
+        error("Not in a git repository.", exit=True)
+    if os.getcwd() != root:
+        error("Must call from the top folder of the git repository",
+              exit=True)
+
+
 def get_root(directory=None):
     """
     Returns the git root directory above the given dir.
